/**
 * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'codesnippet', 'ar', {
	button: 'أدمج قصاصة الشيفرة',
	codeContents: 'محتوى الشيفرة',
	emptySnippetError: 'قصاصة الشيفرة لايمكن أن تكون فارغة.',
	language: 'لغة',
	title: 'قصاصة الشيفرة',
	pathName: 'قصاصة الشيفرة'
} );
