/**
 * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'codesnippet', 'ru', {
	button: 'Вставить сниппет',
	codeContents: 'Содержимое кода',
	emptySnippetError: 'Сниппет не может быть пустым',
	language: 'Язык',
	title: 'Сниппет',
	pathName: 'сниппет'
} );
