/**
 * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'codesnippet', 'fa', {
	button: 'قرار دادن کد قطعه',
	codeContents: 'محتوای کد',
	emptySnippetError: 'کد نمی تواند خالی باشد.',
	language: 'زبان',
	title: 'کد قطعه',
	pathName: 'کد قطعه'
} );
